# crewai-research-demo
A simple demonstration of crewAI's AI Agent framework to perform a research task and summarise findings

> [!IMPORTANT]  
> You will need to create a .env file and populate it with the following environment variables:
- OPENAI_API_KEY